@@ -148,7 +148,7 @@ class ReviewAssigner:
         project = self.cnx.projects.get(merge_request.project_id)
         members_with_review_access = (
             member
-            for member in project.members.list(all=True, as_list=False)
+            for member in project.members_all.list(as_list=False)
             if self.user_can_review(member, project, merge_request)
         )
 
